#
# spec file for package freerdp
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define major_version 2
%define uwac_version 0
%define uwac_package %{uwac_version}-%{uwac_version}
%define version_file 2.0.0-rc1
Name:           freerdp
Version:        2.0.0~rc1
Release:        lp150.2.5
Summary:        Remote Desktop Viewer Client
License:        Apache-2.0
Group:          Productivity/Networking/Other
URL:            http://www.freerdp.com/
Source0:        https://github.com/FreeRDP/FreeRDP/archive/%{version_file}.tar.gz#/FreeRDP-%{version_file}.tar.gz
BuildRequires:  chrpath
BuildRequires:  cmake >= 2.8
BuildRequires:  cups-devel
BuildRequires:  ed
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libgsm-devel
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig
BuildRequires:  xmlto
BuildRequires:  xorg-x11-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(krb5)
BuildRequires:  pkgconfig(libpcsclite)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xkbfile)

%description
FreeRDP is a client-side implementation of the Remote Desktop Protocol (RDP)
following the Microsoft Open Specifications. This package provides the client
application.

%package wayland
Summary:        Remote Desktop Viewer Client
Group:          Productivity/Networking/Other

%description wayland
FreeRDP is a client-side implementation of the Remote Desktop Protocol (RDP)
following the Microsoft Open Specifications. This package provides the
wayland-based client application.

%package server
Summary:        Remote Desktop Server
Group:          Productivity/Networking/Other

%description server
This package contains a server-side implementation which can export a desktop
via the Remote Desktop Protocol (RDP) following the Microsoft Open
Specifications.

%package -n lib%{name}%{major_version}
Summary:        Remote Desktop Viewer client library
Group:          System/Libraries
Obsoletes:      lib%{name} < %{version}-%{release}
Provides:       lib%{name} = %{version}-%{release}

%description -n lib%{name}%{major_version}
FreeRDP is a client-side implementation of the Remote Desktop Protocol (RDP)
following the Microsoft Open Specifications. This package provides the shared
libraries used by the client.

%package devel
Summary:        Development Files for freerdp
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{major_version} = %{version}-%{release}

%description devel
This package contains development files necessary for developing applications
based on libfreerdp.

%package -n     libwinpr%{major_version}
Summary:        Windows Portable Runtime
Group:          Productivity/Networking/Other

%description -n libwinpr%{major_version}
WinPR provides API compatibility for applications targeting non-Windows
environments. When on Windows, the original native API is being used instead of
the equivalent WinPR implementation, without having to modify the code using it.

%package -n winpr%{major_version}-devel
Summary:        Windows Portable Runtime development files
Group:          Development/Languages/C and C++
Requires:       cmake >= 2.8
Requires:       libwinpr%{major_version} = %{version}-%{release}
Obsoletes:      libwinpr2-devel < %{version}-%{release}
Provides:       libwinpr2-devel = %{version}-%{release}

%description -n winpr%{major_version}-devel
This package contains header files for developing applications that
use the winpr and winpr-tools libraries.

%package -n     libuwac%{uwac_package}
Summary:        Use wayland as a client
Group:          Productivity/Networking/Other

%description -n libuwac%{uwac_package}
Using wayland as a client (uwac) is a library to provide common
functionality for wayland clients.

%package -n uwac%{uwac_package}-devel
Summary:        Remote Desktop Toolkit libuwac development files
Group:          Development/Languages/C and C++
Requires:       cmake >= 2.8
Requires:       libuwac%{uwac_package} = %{version}-%{release}
Obsoletes:      libuwac0-devel < %{version}-%{release}
Provides:       libuwac0-devel = %{version}-%{release}

%description -n uwac%{uwac_package}-devel
This package contains header files for developing applications that
use the uwac library.

%prep
%setup -q -n FreeRDP-%{version_file}
%if 0%{?sles_version} == 11
    cp %{SOURCE1} cmake/
%endif

%build
find . -type f -name "*.c" -exec perl -i -pe 's{__(DATE|TIME)__}{""}g' "{}" "+"
export LDFLAGS="-pie"
export CFLAGS="%{optflags} -fPIE -pie"

# enable -DWITH_GSSAPI=ON again after #gh/FreeRDP/FreeRDP/4348 has been fixed
%cmake \
	-DCMAKE_INSTALL_PREFIX=%{_prefix} \
	-DCMAKE_INSTALL_LIBDIR=%{_lib} \
	-DCMAKE_BUILD_TYPE=Release \
	-DCMAKE_SKIP_RPATH=ON \
	-DWITH_ALSA=ON \
	-DWITH_PCSC=ON \
	-DWITH_CUPS=ON \
%ifarch %{ix86} x86_64
	-DWITH_SSE2=ON \
%endif
	-DWITH_CLIENT=ON \
	-DWITH_SERVER=ON \
	-DWITH_CHANNELS=ON -DBUILTIN_CHANNELS=OFF \
	-DWITH_DIRECTFB=OFF \
	-DWITH_FFMPEG=OFF \
	-DWITH_GSM=ON \
	-DWITH_GSTREAMER_1_0=ON \
	-DWITH_ICU=ON \
	-DWITH_IPP=OFF \
	-DWITH_JPEG=ON \
	-DWITH_KRB5=ON \
	-DWITH_LIBRARY_VERSIONING=ON \
	-DWITH_OPENSSL=ON \
	-DWITH_X11=ON \
	-DWITH_XCURSOR=ON \
	-DWITH_XEXT=ON \
	-DWITH_XKBFILE=ON \
	-DWITH_XI=ON \
	-DWITH_XINERAMA=ON \
	-DWITH_XRENDER=ON \
	-DWITH_XV=ON \
	-DWITH_ZLIB=ON

make %{?_smp_mflags}

%install
cd build
%make_install
%fdupes %{buildroot}%{_libdir}/cmake/

%post   -n lib%{name}%{major_version} -p /sbin/ldconfig
%postun -n lib%{name}%{major_version} -p /sbin/ldconfig
%post -n libwinpr%{major_version} -p /sbin/ldconfig
%postun -n libwinpr%{major_version} -p /sbin/ldconfig
%post -n libuwac%{uwac_package} -p /sbin/ldconfig
%postun -n libuwac%{uwac_package} -p /sbin/ldconfig

%files
%{_bindir}/x%{name}
%{_mandir}/man1/x%{name}.1%{ext_man}
%{_mandir}/man7/wlog.7%{ext_man}

%files wayland
%{_bindir}/wl%{name}
%{_mandir}/man1/wl%{name}.1%{ext_man}

%files server
%{_bindir}/%{name}-shadow-cli
%{_bindir}/winpr-hash
%{_bindir}/winpr-makecert
%{_mandir}/man1/%{name}-shadow-cli.1%{ext_man}
%{_mandir}/man1/winpr-hash.1%{ext_man}
%{_mandir}/man1/winpr-makecert.1%{ext_man}

%files -n lib%{name}%{major_version}
%doc LICENSE
%{_libdir}/%{name}%{major_version}
%{_libdir}/lib%{name}%{major_version}.so.*
%{_libdir}/lib%{name}-client%{major_version}.so.*
%{_libdir}/lib%{name}-shadow%{major_version}.so.*
%{_libdir}/lib%{name}-server%{major_version}.so.*
%{_libdir}/lib%{name}-shadow-subsystem%{major_version}.so.*

%files devel
%{_libdir}/cmake/FreeRDP%{major_version}
%{_libdir}/cmake/FreeRDP-Client%{major_version}
%{_libdir}/cmake/FreeRDP-Server%{major_version}
%{_libdir}/cmake/FreeRDP-Shadow%{major_version}
%{_includedir}/%{name}%{major_version}
%{_libdir}/lib%{name}*.so
%{_libdir}/pkgconfig/%{name}%{major_version}.pc
%{_libdir}/pkgconfig/%{name}-client%{major_version}.pc
%{_libdir}/pkgconfig/%{name}-server%{major_version}.pc
%{_libdir}/pkgconfig/%{name}-shadow%{major_version}.pc

%files -n libwinpr%{major_version}
%doc LICENSE
%{_libdir}/libwinpr%{major_version}.so.*
%{_libdir}/libwinpr-tools%{major_version}.so.*

%files -n winpr%{major_version}-devel
%{_libdir}/cmake/WinPR%{major_version}
%{_includedir}/winpr%{major_version}
%{_libdir}/libwinpr%{major_version}.so
%{_libdir}/libwinpr-tools%{major_version}.so
%{_libdir}/pkgconfig/winpr%{major_version}.pc
%{_libdir}/pkgconfig/winpr-tools%{major_version}.pc

%files -n libuwac%{uwac_package}
%doc LICENSE
%{_libdir}/libuwac%{uwac_version}.so.*

%files -n uwac%{uwac_package}-devel
%{_libdir}/cmake/uwac%{uwac_version}
%{_includedir}/uwac%{uwac_version}
%{_libdir}/libuwac%{uwac_version}.so
%{_libdir}/pkgconfig/uwac%{uwac_version}.pc

%changelog
* Thu Jan 11 2018 jweberhofer@weberhofer.at
- Users can connect only once wo windows sessions due to
  [#]gh/FreeRDP/FreeRDP/4348
  Therefore WITH_GSSAPI has been disabled until that issue has been
  solved
* Thu Nov 30 2017 jweberhofer@weberhofer.at
- Updated to 2.0.0-rc1
  Noteworthy features and improvements:
  * support for FIPS mode was added (option +fipsmode)
  * initial client side kerberos support (run cmake with WITH_GSSAPI)
  * support for ssh-agent redirection (as rdp channel)
  * the man page(s) and /help were updated an improved
  * add support for ICU for unicode conversion (-DWITH_ICU=ON)
  * client add option to force password prompt before connection (/from-stdin[:force])
  * extend /size to allow width or height percentages (#gh/FreeRDP/FreeRDP/4146)
  * add support for "password is pin"
  * clipboard is now enabled per default (use -clipboard to disable)
  Fixed github issues (excerpt):
  * #gh/FreeRDP/FreeRDP/4281: Added option to prefer IPv6 over IPv4
  * #gh/FreeRDP/FreeRDP/3890: Point to OpenSSL doc for private CA
  * #gh/FreeRDP/FreeRDP/3378: support 31 static channels as described in the spec
  * #gh/FreeRDP/FreeRDP/4253: Rfx decode tile width.
  * #gh/FreeRDP/FreeRDP/3267: fix parsing of drivestoredirect
  * #gh/FreeRDP/FreeRDP/4257: Proper error checks for /kbd argument
  * #gh/FreeRDP/FreeRDP/4249: Corruption due to recursive parser
  * #gh/FreeRDP/FreeRDP/4111: 15bpp color handling for brush.
  * #gh/FreeRDP/FreeRDP/3509: Added Ctrl+Alt+Enter description
  * #gh/FreeRDP/FreeRDP/3211: Return freerdp error from main.
  * #gh/FreeRDP/FreeRDP/3513: add better description for drive redirection
  * #gh/FreeRDP/FreeRDP/4199: ConvertFindDataAToW string length
  * #gh/FreeRDP/FreeRDP/4135: client/x11: fix colors on big endian
  * #gh/FreeRDP/FreeRDP/4089: fix h264 context leak when DeleteSurface
  * #gh/FreeRDP/FreeRDP/4117: possible segfault
  * #gh/FreeRDP/FreeRDP/4091: fix a regression with remote program
* Mon Sep  4 2017 jengelh@inai.de
- Remove extraneous Obsoletes for packages that never existed
  in openSUSE:Factory or X11:RemoteDesktop.
- Rename libuwac0-devel to uwac0-devel and libwinpr-devel to
  winpr-devel, as that seems to be their upstream name which
  packages are encouraged to stick to.
- Remove duplicated pkgconfig requires (these are autodetected).
* Fri Sep  1 2017 jweberhofer@weberhofer.at
- Fixed download location
* Fri Sep  1 2017 jweberhofer@weberhofer.at
- Switched to official RC0
- Create wayland client package and libuwac0 package
- Create separate libwinpr2 to be used in other packages
- enabled gstreamer (currently disabled for tumbleweed)
- enabled kerberos authentication
- Update to official RC0
  Fix the following issues identified by the CISCO TALOS project:
  * TALOS-2017-0336 CVE-2017-2834 boo#1050714
  * TALOS-2017-0337 CVE-2017-2835 boo#1050712
  * TALOS-2017-0338 CVE-2017-2836 boo#1050699
  * TALOS-2017-0339 CVE-2017-2837 boo#1050704
  * TALOS-2017-0340 CVE-2017-2838 boo#1050708
  * TALOS-2017-0341 CVE-2017-2839 boo#1050711
* Sun Jun 11 2017 bruno@ioda-net.ch
- Redo history by using changelog url
- Update to version 2.0.0~git.1497095982.1dbd2d28d:
  See https://github.com/freerdp/freeRDP/compare/043243f...1dbd2d28d
  for full details.
- Packaging :
  + Move to xz tarball in _service
  + Remove 3472.patch merged upstream
- Update to version 2.0.0~git.1496304402.c42ccb508:
  See https://github.com/freerdp/freeRDP/compare/043243f...c42ccb508
  for changes.
* Sat Jun 10 2017 meissner@suse.com
- Forcefully enable PIE in CFLAGS as the automatism did not work.
* Tue Jan 17 2017 bruno@ioda-net.ch
- Add 3472.patch until upstream #3472 isssue is fixed and PR merged
  this fix boo#1004108
* Wed Oct 26 2016 dimstar@opensuse.org
- Update to version 2.0.0~git.1477034991.043243f:
  * fixed kerberos authentication
  * shadow/rdpsnd: Fix race condition in rdpsnd channel server.
    The output buffer and format parameters are not protected.
  * wfreerdp: fix invalid VerifyCertificate callback
  * rdpsnd/server: decrease audio latency and make it configurable.
  * Add an environment variables section to the man
  * protocol violation: rdp_read_extended_info_packet
  * Added support for OpenH264 1.6
  * freerdp: fix sending of TLS alert on NLA failure, add better
    handling of server-side NLA in shadow server
  * freerdp: add configurable NTLM SAM file option for
    server-side NLA
  * freerdp: make modifications to NLA server-side fixes according
    to PR comments
  * Fixed a windows 8.1 issue.
* Wed May 18 2016 jengelh@inai.de
- Kill off __DATE__ from built sources.
* Tue May 17 2016 fezhang@suse.com
- Update to GNOME 3.20.2 FATE#318572
- Add obs git integration.
- Update to version 2.0.0git.1463131968.4e66df7:
  + Fixed memory leaks.
  + wfreerdp: fix name build without client interface
  + libfreerdp-codec: fix xcrush decompression, revert remote
    control fix
  + KB3153731: May 2016 DST update for Azerbaijan, Chile, Haiti and
    Morocco
  + libfreerdp-codec: make proper xcrush context reset fix
* Wed May  4 2016 fezhang@suse.com
- Update to version 2.0.0, git master branch id a7ca42e
  (FATE#319661), no upstream changelog available.
  * Warning: This is a git snapshot regarded as technical preview
    by upstream.
  * Warning: For xfreerdp, new /long-option commandline interfaces
    have replaced the old --long-option interfaces. Existing user
    scripts need to migrate to the new interfaces to avoid
    breakages.
    For more details, see:
    https://github.com/FreeRDP/FreeRDP/wiki/CommandLineInterface
  * Add Network Level Ahthentication support.
  * Add Windows Portable Runtime. For more details, see:
    http://www.freerdp.com/2012/05/24/winpr-windows-portable-runtime
  * Obsolete libfreerdp-1_0-plugins.
- Drop FindALSA.cmake: deprecated
- Drop freerdp_branch-1.0.x_fix-kpdivide-issue831.patch:
  fixed upstream, implemention now in include/freerdp/scancode.h.
- Drop freerdp-CVE-2014-0250.patch (bnc#880317):
  fixed upstream 532c420.
- Drop freerdp-CVE-2014-0791.patch (bnc#857491):
  fixed upstream f1d6afc.
- Drop freerdp-fix-FindPCSC-macro.patch:
  fixed upstream 9148af3.
- Drop freerdp-handle-null-device-name.patch (bnc#785437):
  deprecated, related implementation dropped.
  was: freerdp-fix-pulse-no-device-name.patch
* Mon Jun 23 2014 fezhang@suse.com
- Add freerdp-CVE-2014-0791.patch to fix bnc#857491
  backported from upstream commit f1d6afc
* Thu Jun 12 2014 dliang@suse.com
- Add freerdp-CVE-2014-0250.patch to fix bnc#880317
  solves CVE-2014-0250, backport from upstream
* Thu Oct 31 2013 lnt-sysadmin@lists.lrz.de
- Allow build on SLES11:
  * converted pkgconfig() BuildRequires to package names
  * added FindALSA.cmake
  * use 'make install' instead of '%%make_install' macro
* Thu Sep 12 2013 crrodriguez@opensuse.org
- build with -DOPENSSL_LOAD_CONF so among other things
  the application respects the system's openSSL configuration.
* Thu Mar  7 2013 bruno@ioda-net.ch
- Added patch for issue #811 fixing divide key (/) on keypad for
  1.0x series,
  commit https://github.com/bmiklautz/FreeRDP/commit/e0cc1e60657b5883a907e5da2f70eb27bf0b91f1
- Added changelog
  FreeRDP 1.0.2 is a maintenance release which contains several bug
  and stability fixes.
  * xfreerdp:
  * new parameter --from-stdin - prompts for unspecified arguments
    username, password, domain and host.
  * fix compability with x2go
  * fix keyboard state in remote app
  * documentation fixes
  * fixed crash when started with --authonly (#843)
  * libfreerdp-core:
  * several memory leaks and double frees were fixed
  * support for FastPath PDUs up to 32767
  * register audio only if plugin is registered
  * load extensions after argument parsing
  * libfreerdp-utils:
  * fixed crash when HOME environment variable wasn't set
  * xfreerdp-server:
  * deadlock fixed
  * accept TLSv1 and SSLv3
  * smartcard:
  * don't incorrectly set SCARD_STATE_IGNORE
  * libfreerdp-codec:
  * performance improvement
  * libfreerdp-gdi:
  * support for PatBlt DPa operation
  * plugin:
  * ignore CHANNEL_FLAG_SUSPEND/CHANNEL_FLAG_RESUME to prevent
    possible crash
  For a detailed list of changes use "git log 1.0.1..1.0.2"
  known problems:
  * If windows input language is set to german pressing the divde
    key (/) on the keypad results in minus (-) (see issue #811)
* Thu Jan 24 2013 kkaempf@suse.com
- update to 1.0.2
  - bugfix release (no changelog posted)
  - drop patches that are upstream
* Fri Dec 28 2012 dmueller@suse.com
- only enable SSE2 on x86*
* Fri Dec 28 2012 dvaleev@suse.com
- disable SSE2 for ARM as well
* Fri Dec 28 2012 dvaleev@suse.com
- disable SSE2 for powerpc
* Thu Dec 27 2012 gber@opensuse.org
- build with WITH_SSE2=ON as freerdp now uses runtime detection
  (bnc#793611)
* Thu Nov  1 2012 gber@opensuse.org
- added freerdp-fix-pulse-no-device-name.patch in order to fix a
  segfault in case device name is not provided (bnc#785437)
* Wed Oct 17 2012 gber@opensuse.org
- added freerdp-fix-linking-with-libpulse.patch in order to link
  correctly with libpulse
  (https://github.com/FreeRDP/FreeRDP/issues/418, bnc#785437)
* Sun Apr 29 2012 zawertun@gmail.com
- added freerdp-fix-incorrect-numlock-state.patch which fixes
  incorrect num lock state when connecting
  (https://github.com/FreeRDP/FreeRDP/pull/564)
* Sun Apr 22 2012 gber@opensuse.org
- added freerdp-fix-FindPCSC-macro.patch which fixes the build by
  setting PCSC_LIBRARIES and PCSC_INCLUDE_DIRS variables explicitly
  which are otherwise empty
  (https://github.com/FreeRDP/FreeRDP/issues/562)
* Thu Apr 19 2012 gber@opensuse.org
- applied fix for a bug in freerdp-fix-bitmap-cache.patch from
  upstream git
* Fri Mar 30 2012 zawertun@gmail.com
- added freerdp-fix-bitmap-cache.patch fixing a problem with the
  bitmap cache resulting in garbled images
  (https://github.com/FreeRDP/FreeRDP/issues/348)
* Wed Mar 28 2012 gber@opensuse.org
- split off -plugins subpackage
- specfile cleanup
* Tue Mar  6 2012 gankov@opensuse.org
- rewrote spec for using cmake.
- update to version 1.0.1
  - FreeRDP 1.x series is a complete rewrite now licensed under
    the Apache License 2.0
  - RemoteFX
  - Both encoder and decoder
  - SSE2 and NEON optimization
  - NSCodec
  - RemoteApp
  - Working, minor glitches
  - Multimedia Redirection
  - ffmpeg support
  - Network Level Authentication (NLA)
  - NTLMv2
  - Certificate validation
  - FIPS-compliant RDP security
  - new build system (cmake)
  - added official logo and icon
* Fri Dec  2 2011 gber@opensuse.org
- add explicit dependency on libtool
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Sep 22 2011 gber@opensuse.org
- cleanup to comply with the packaging policy
  - add header
  - use the correct license format
  - remove %%clean section
  - simplify the manipulation of PLUGIN_PATH
  - remove %%debug_package
  - add meaningful description
  - do not recompres the source tarball any more
  - corrected URLs
* Tue Jun  7 2011 pascal.bleser@opensuse.org
- fix bnc#688484 by passing --with-sound=alsa and alsa-devel in
  BuildRequires
* Wed Nov 17 2010 pascal.bleser@opensuse.org
- rewrote most of the spec file (wrong group, wrong subpackages,
  ldconfig called on devel package, shlibs inj devel package, ...)
- update to 0.8.2:
  * libfreerdp:
    + fix buffer overflow when local timezone doesn't fit in 32
    bytes
    + fix data corruption after TLS license package
    + free TLS resources to avoid memory leaks
  * mcs:
    + fix connecting to VirtualBox with extra channels
  * rdpsnd plugin:
    + ensure the ALSA device is closed when freeing resources
  * rdpdr plugin:
    + fix various memory leaks
    + fix a segfault in multi-session environment
* Wed Oct 27 2010 hrustov@gmail.com
- initial build
